============
Installation
============

At the command line::

    $ easy_install cybak-lzma

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv cybak-lzma
    $ pip install cybak-lzma
